Rect

Struct Rect 

pub struct Rect<T> {
    pub origin: Point2D<T>,
    pub size: Size<T>,
}
A generic rectangle with an origin and size.

Fields

origin: Point2D<T>

Rectangle origin.

size: Size<T>

Rectangle size.

Implementations

Source

impl<T: Copy> Rect<T>

pub fn new(origin: impl Into<Point2D<T>>, size: impl Into<Size<T>>) -> Self

Create a new rectangle.

pub fn points(min: impl Into<Point2D<T>>, max: impl Into<Point2D<T>>) -> Self
where T: Sub<Output = T>,

Create a rectangle from a bottom-left and top-right point.

pub fn map<S, F>(self, f: F) -> Rect<S>
where F: Fn(T) -> S,

Map the origin and size of a rectangle.

pub fn expand(&self, x: T, y: T) -> Self
where T: Add<Output = T> + Sub<Output = T>,

Expand a rectangle’s area.

Source

impl<T: Copy> Rect<T>

pub fn origin(size: impl Into<Size<T>>) -> Self
where T: Zero,

Create a rectangle with a zero origin.

pub fn scale(&self, s: T) -> Self
where T: Mul<Output = T> + Copy,

Scale a rectangle’s size.

pub fn with_origin(&self, origin: impl Into<Point2D<T>>) -> Self
where T: Add<Output = T> + Sub<Output = T> + Copy,

Return the rectangle with a different origin.

Examples
use ombre::math::Rect;

let r = Rect::new([1, 1], [4, 4]);
assert_eq!(r.with_origin([0, 0]), Rect::new([0, 0], [4, 4]));
pub fn with_size(&self, size: impl Into<Size<T>>) -> Self
where T: Add<Output = T> + Sub<Output = T> + Copy,

Return the rectangle with a different size.

Examples
use ombre::math::Rect;

let r = Rect::new([1, 1], [4, 4]);
assert_eq!(r.with_size([9, 9]), Rect::new([1, 1], [9, 9]));
pub fn area(&self) -> T
where T: Copy + Sub<Output = T> + PartialOrd + Mul<Output = T>,

Return the area of a rectangle.

pub fn is_empty(&self) -> bool
where T: Zero,

Check whether the rectangle has a zero size.

pub fn is_zero(&self) -> bool
where T: Zero,

Check whether the rectangle has a zero size and its origin is zero.

pub fn width(&self) -> T

Return the width of the rectangle.

Examples
use ombre::math::Rect;

let r = Rect::new([0, 0], [3, 3]);
assert_eq!(r.width(), 3);
pub fn height(&self) -> T

Return the height of the rectangle.

Examples
use ombre::math::Rect;

let r: Rect<u64> = Rect::origin([6, 6]);
assert_eq!(r.height(), 6);
pub fn center(&self) -> Point2D<T>
where T: Two + Div<Output = T> + Add<Output = T>,

Return the center of the rectangle.

Examples
use ombre::math::Rect;
use ombre::math::Point2D;

let r = Rect::origin([8, 8]);
assert_eq!(r.center(), Point2D::new(4, 4));

let r = Rect::new([0, 0], [-8, -8]);
assert_eq!(r.center(), Point2D::new(-4, -4));
pub fn radius(&self) -> T
where T: Two + Div<Output = T> + PartialOrd + Sub<Output = T>,

Return the radius of the rectangle.

pub fn contains(&self, point: impl Into<Point2D<T>>) -> bool
where T: PartialOrd + Add<Output = T>,

Check whether the given point is contained in the rectangle.

use ombre::math::{Point2D, Rect};

let r = Rect::origin([6, 6]);
assert!(r.contains([0, 0]));
assert!(r.contains([3, 3]));
assert!(!r.contains([6, 6]));

let r = Rect::new([-6, -6], [6, 6]);
assert!(r.contains([-3, -3]));
pub fn min(&self) -> Point2D<T>

Get the minimum point.

pub fn max(&self) -> Point2D<T>
where T: Add<Output = T>,

Get the maximum point.

pub fn intersects(&self, other: Rect<T>) -> bool
where T: PartialOrd + Add<Output = T>,

Check whether this rectangle intersects with another.

pub fn intersection(&self, other: Rect<T>) -> Option<Self>
where T: Ord + Add<Output = T> + Sub<Output = T>,

Return the intersection between two rectangles.

Examples
use ombre::math::Rect;

let other = Rect::points([0, 0], [3, 3]);

let r = Rect::points([1, 1], [6, 6]);
assert_eq!(r.intersection(other), Some(Rect::points([1, 1], [3, 3])));

let r = Rect::points([1, 1], [2, 2]);
assert_eq!(r.intersection(other), Some(Rect::points([1, 1], [2, 2])));

let r = Rect::points([-1, -1], [3, 3]);
assert_eq!(r.intersection(other), Some(Rect::points([0, 0], [3, 3])));

let r = Rect::points([-1, -1], [4, 4]);
assert_eq!(r.intersection(other), Some(other));

let r = Rect::points([4, 4], [5, 5]);
assert_eq!(r.intersection(other), None);
assert_eq!(other.intersection(r), None);